@@ -14,6 +14,7 @@ globalVariables("holiday")
 #' * AFL public holidays for Victoria
 #' * Queen's Birthday for Western Australia
 #' * Royal Queensland Show for Queensland, which is for Brisbane only
+#' This function requires "timeDate" to be installed.
 #' @references
 #' [Public holidays](https://www.australia.gov.au/about-australia/special-dates-and-events/public-holidays)
 #' @export
@@ -22,6 +23,12 @@ globalVariables("holiday")
 #' holiday_aus(2016, state = "VIC")
 #' holiday_aus(2013:2016, state = "ACT")
 holiday_aus <- function(year, state = "national") {
+  if (!requireNamespace("timeDate", quietly = TRUE)) {
+    abort(
+      "Package timeDate required for holiday_aus()", ".\n",
+      "Please install and try again."
+    )
+  }
   if (!is.numeric(year)) {
     abort("`year` must be double/integer.")
   }
