@@ -16,11 +16,11 @@
 #' * [stretch] for expanding more observations
 #'
 #' @examples
-#' .x <- 1:5
-#' .lst <- list(x = .x, y = 6:10, z = 11:15)
-#' tile_dbl(.x, mean, .size = 2)
-#' tile_lgl(.x, ~ mean(.) > 2, .size = 2)
-#' tile(.lst, ~ ., .size = 2)
+#' x <- 1:5
+#' lst <- list(x = x, y = 6:10, z = 11:15)
+#' tile_dbl(x, mean, .size = 2)
+#' tile_lgl(x, ~ mean(.) > 2, .size = 2)
+#' tile(lst, ~ ., .size = 2)
 tile <- function(.x, .f, ..., .size = 1) {
   lst_x <- tiler(.x, .size = .size)
   purrr::map(lst_x, .f, ...)
@@ -66,18 +66,17 @@ tile_dfc <- function(.x, .f, ..., .size = 1) {
 #' * [tile]
 #' * [slide2] for sliding window with overlapping observations
 #' * [stretch2] for expanding more observations
-#'
 #' @examples
-#' .x <- 1:5
-#' .y <- 6:10
-#' .z <- 11:15
-#' .lst <- list(x = .x, y = .y, z = .z)
-#' .df <- as.data.frame(.lst)
-#' tile2(.x, .y, sum, .size = 2)
-#' tile2(.lst, .lst, ~ ., .size = 2)
-#' tile2(.df, .df, ~ ., .size = 2)
-#' ptile(.lst, sum, size = 1)
-#' ptile(list(.lst, .lst), ~ ., .size = 2)
+#' x <- 1:5
+#' y <- 6:10
+#' z <- 11:15
+#' lst <- list(x = x, y = y, z = z)
+#' df <- as.data.frame(lst)
+#' tile2(x, y, sum, .size = 2)
+#' tile2(lst, lst, ~ ., .size = 2)
+#' tile2(df, df, ~ ., .size = 2)
+#' ptile(lst, sum, .size = 1)
+#' ptile(list(lst, lst), ~ ., .size = 2)
 tile2 <- function(.x, .y, .f, ..., .size = 1) {
   lst <- ptiler(.x, .y, .size = .size)
   purrr::map2(lst[[1]], lst[[2]], .f, ...)
@@ -111,9 +110,6 @@ tile2_dfc <- function(.x, .y, .f, ..., .size = 1) {
 #' @rdname tile2
 #' @export
 ptile <- function(.l, .f, ..., .size = 1) {
-  if (is.data.frame(.l)) {
-    .l <- as.list(.l)
-  }
   lst <- ptiler(!!! .l, .size = .size)
   purrr::pmap(lst, .f, ...)
 }
@@ -132,16 +128,14 @@ for(type in c("lgl", "chr", "dbl", "int")){
 #' @rdname tile2
 #' @export
 ptile_dfr <- function(.l, .f, ..., .size = 1, .id = NULL) {
-  lst <- tiler(.l, .size = .size)
-  out <- purrr::pmap(lst, .f, ...)
+  out <- ptile(.l, .f, ..., .size = .size)
   dplyr::bind_rows(!!! out, .id = .id)
 }
 
 #' @rdname tile2
 #' @export
 ptile_dfc <- function(.l, .f, ..., .size = 1) {
-  lst <- tiler(.l, .size = .size)
-  out <- purrr::pmap(lst, .f, ...)
+  out <- ptile(.l, .f, ..., .size = .size)
   dplyr::bind_cols(!!! out)
 }
 
@@ -151,39 +145,30 @@ ptile_dfc <- function(.l, .f, ..., .size = 1) {
 #' @rdname tiler
 #' @export
 #' @examples
-#' .x <- 1:5
-#' .y <- 6:10
-#' .z <- 11:15
-#' .lst <- list(x = .x, y = .y, z = .z)
-#' .df <- as.data.frame(.lst)
+#' x <- 1:5
+#' y <- 6:10
+#' z <- 11:15
+#' lst <- list(x = x, y = y, z = z)
+#' df <- as.data.frame(lst)
 #' 
-#' tiler(.x, .size = 2)
-#' tiler(.lst, .size = 2)
-#' ptiler(.lst, .size = 2)
-#' ptiler(list(.x, .y), list(.y))
-#' ptiler(.df, .size = 2)
-#' ptiler(.df, .df, .size = 2)
+#' tiler(x, .size = 2)
+#' tiler(lst, .size = 2)
+#' ptiler(lst, .size = 2)
+#' ptiler(list(x, y), list(y))
+#' ptiler(df, .size = 2)
+#' ptiler(df, df, .size = 2)
 tiler <- function(.x, .size = 1) {
-  if (is.data.frame(.x)) .x <- as.list(.x)
-  tiler_base(.x, .size = .size)
+  bad_window_function(.size)
+  len_x <- NROW(.x)
+  seq_x <- seq_len(len_x)
+  denom <- len_x + 1
+  frac <- ceiling((seq_x %% denom) / .size)
+  unname(split(.x, frac, drop = TRUE))
 }
 
 #' @rdname tiler
 #' @export
 ptiler <- function(..., .size = 1) { # parallel sliding
   lst <- recycle(list2(...))
-  df_lgl <- purrr::map_lgl(lst, is.data.frame)
-  if (any(df_lgl)) {
-    lst[df_lgl] <- purrr::map(lst[df_lgl], as.list)
-  }
-  purrr::map(lst, function(x) tiler_base(x, .size = .size))
-}
-
-tiler_base <- function(x, .size = 1) {
-  bad_window_function(.size)
-  len_x <- NROW(x)
-  seq_x <- seq_len(len_x)
-  denom <- len_x + 1
-  frac <- ceiling((seq_x %% denom) / .size)
-  unname(split(x, frac, drop = TRUE))
+  purrr::map(lst, function(x) tiler(x, .size = .size))
 }
