@@ -74,10 +74,17 @@ dont_know <- function(x, FUN) {
 }
 
 unknown_interval <- function(x) {
-  not_zero <- !purrr::map_lgl(x, function(x) x == 0)
-  # if output is empty, it means that duplicated time entries
-  # if output is NA, it means that only one time entry
-  if (anyNA(not_zero)) {
-    abort("Cannot deal with data of unknown interval.")
-  }
+  no_zeros <- !purrr::map_lgl(x, function(x) x == 0)
+  if (sum(no_zeros) == 0) abort("Cannot deal with data of unknown interval.")
+}
+
+is_even <- function(x) {
+  (abs(x) %% 2) == 0
+}
+
+identical_type <- function(x, y) {
+  if (identical(x, y)) 
+    return(x) 
+  else 
+    abort("Don't know how to bind list elements of different types.")
 }
