@@ -5,22 +5,22 @@ test_that("a ts with different frequnecy", {
   tsbl1 <- as_tsibble(x1)
   expect_identical(dim(tsbl1), c(length(x1), 2L))
   expect_identical(key_vars(tsbl1), character(0))
-  expect_identical(format(interval(tsbl1)), "1UNIT")
+  expect_identical(format(interval(tsbl1)), "1")
   x2 <- ts(1:10, start = 2000)
   tsbl2 <- as_tsibble(x2)
-  expect_identical(format(interval(tsbl2)), "1YEAR")
+  expect_identical(format(interval(tsbl2)), "1Y")
   x3 <- ts(1:10, start = c(2000, 1), frequency = 4)
   tsbl3 <- as_tsibble(x3)
-  expect_identical(format(interval(tsbl3)), "1QUARTER")
+  expect_identical(format(interval(tsbl3)), "1Q")
   x4 <- ts(1:10, start = c(2000, 1), frequency = 12)
   tsbl4 <- as_tsibble(x4)
-  expect_identical(format(interval(tsbl4)), "1MONTH")
+  expect_identical(format(interval(tsbl4)), "1M")
   x5 <- ts(1:10, start = c(2000, 1), frequency = 7)
   tsbl5 <- as_tsibble(x5)
-  expect_identical(format(interval(tsbl5)), "1DAY")
+  expect_identical(format(interval(tsbl5)), "1D")
   x6 <- ts(1:10, start = c(2000, 1), frequency = 52)
   tsbl6 <- as_tsibble(x6)
-  expect_identical(format(interval(tsbl6)), "1WEEK")
+  expect_identical(format(interval(tsbl6)), "1W")
 })
 
 test_that("a mts", {
